#========================================================================================
# package      DE_EPAGES::Ipayment::t::unit::Requirement
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Ipayment::API::Requirement
#========================================================================================
package DE_EPAGES::Ipayment::t::unit::Requirement;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::EpagesObject;
use DE_EPAGES::Test::Mock::Mockify;
use Test::More;

use strict;



sub test {
    my $self = shift;

    $self->test_areMandatoryFieldsSet_Positive();
    $self->test_areMandatoryFieldsSet_Negative();
    $self->test_areMandatoryFieldsSet_Negative_OnlyOneFieldSet();
    $self->test_areMandatoryFieldsSet_Negative_NoFieldSet();

    done_testing();
}



sub test_areMandatoryFieldsSet_Positive {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop_WithAllMandatoryFieldsSet();
    my $Requirement = $self->_createRequirement($Shop);

    my $AreMandatoryFieldsSet = $Requirement->areMandatoryFieldsSet();

    ok($AreMandatoryFieldsSet, "$SubTestName - tests if all mandatory fields are set");
}



sub test_areMandatoryFieldsSet_Negative {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop_WithNotAllMandatoryFieldsSet();
    my $Requirement = $self->_createRequirement($Shop);

    my $AreMandatoryFieldsSet = $Requirement->areMandatoryFieldsSet();

    is($AreMandatoryFieldsSet, 0, "$SubTestName - tests if NOT all mandatory fields are set");
}



sub test_areMandatoryFieldsSet_Negative_OnlyOneFieldSet {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop_WithOnlyOneMandatoryFieldsSet();
    my $Requirement = $self->_createRequirement($Shop);

    my $AreMandatoryFieldsSet = $Requirement->areMandatoryFieldsSet();

    is($AreMandatoryFieldsSet, 0, "$SubTestName - tests if NOT all mandatory fields are set");
}



sub test_areMandatoryFieldsSet_Negative_NoFieldSet {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop_WithNoFieldsSet();
    my $Requirement = $self->_createRequirement($Shop);

    my $AreMandatoryFieldsSet = $Requirement->areMandatoryFieldsSet();

    is($AreMandatoryFieldsSet, 0, "$SubTestName - tests if NOT all mandatory fields are set");
}



sub _createRequirement {
    my $self = shift;
    my ($Shop) = @_;

    my $aParameterList = [$Shop];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Ipayment::API::Requirement', $aParameterList);

    return $Mockify->getMockObject();
}



sub _createShop_WithAllMandatoryFieldsSet {
    my $self = shift;
    my $hAttributes = {
        'ShippingAddressSetMandatoryFields' => 'EMail,FirstName,LastName,City,Street,Zipcode,CountryID',
    };
    return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', $hAttributes);
}



sub _createShop_WithNotAllMandatoryFieldsSet {
    my $self = shift;
    my $hAttributes = {
        'ShippingAddressSetMandatoryFields' => 'FirstName,LastName,Zipcode',
    };
    return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', $hAttributes);
}



sub _createShop_WithOnlyOneMandatoryFieldsSet {
    my $self = shift;
    my $hAttributes = {
        'ShippingAddressSetMandatoryFields' => 'FirstName',
    };
    return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', $hAttributes);
}




sub _createShop_WithNoFieldsSet {
    my $self = shift;
    my $hAttributes = {
        'ShippingAddressSetMandatoryFields' => '',
    };
    return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', $hAttributes);
}



__PACKAGE__->runScript();